# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DomainOrganizationRoleUpdate(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DomainOrganizationRoleUpdate - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'default_role_id': 'str',
            'permissions': 'list[str]',
            'unused_permissions': 'list[str]',
            'permission_policies': 'list[DomainPermissionPolicy]',
            'user_count': 'int',
            'role_needs_update': 'bool',
            'default': 'bool',
            'base': 'bool',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'default_role_id': 'defaultRoleId',
            'permissions': 'permissions',
            'unused_permissions': 'unusedPermissions',
            'permission_policies': 'permissionPolicies',
            'user_count': 'userCount',
            'role_needs_update': 'roleNeedsUpdate',
            'default': 'default',
            'base': 'base',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._default_role_id = None
        self._permissions = None
        self._unused_permissions = None
        self._permission_policies = None
        self._user_count = None
        self._role_needs_update = None
        self._default = None
        self._base = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DomainOrganizationRoleUpdate.
        The globally unique identifier for the object.

        :return: The id of this DomainOrganizationRoleUpdate.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DomainOrganizationRoleUpdate.
        The globally unique identifier for the object.

        :param id: The id of this DomainOrganizationRoleUpdate.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DomainOrganizationRoleUpdate.
        The name of the role

        :return: The name of this DomainOrganizationRoleUpdate.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DomainOrganizationRoleUpdate.
        The name of the role

        :param name: The name of this DomainOrganizationRoleUpdate.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this DomainOrganizationRoleUpdate.


        :return: The description of this DomainOrganizationRoleUpdate.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this DomainOrganizationRoleUpdate.


        :param description: The description of this DomainOrganizationRoleUpdate.
        :type: str
        """
        
        self._description = description

    @property
    def default_role_id(self):
        """
        Gets the default_role_id of this DomainOrganizationRoleUpdate.


        :return: The default_role_id of this DomainOrganizationRoleUpdate.
        :rtype: str
        """
        return self._default_role_id

    @default_role_id.setter
    def default_role_id(self, default_role_id):
        """
        Sets the default_role_id of this DomainOrganizationRoleUpdate.


        :param default_role_id: The default_role_id of this DomainOrganizationRoleUpdate.
        :type: str
        """
        
        self._default_role_id = default_role_id

    @property
    def permissions(self):
        """
        Gets the permissions of this DomainOrganizationRoleUpdate.


        :return: The permissions of this DomainOrganizationRoleUpdate.
        :rtype: list[str]
        """
        return self._permissions

    @permissions.setter
    def permissions(self, permissions):
        """
        Sets the permissions of this DomainOrganizationRoleUpdate.


        :param permissions: The permissions of this DomainOrganizationRoleUpdate.
        :type: list[str]
        """
        
        self._permissions = permissions

    @property
    def unused_permissions(self):
        """
        Gets the unused_permissions of this DomainOrganizationRoleUpdate.
        A collection of the permissions the role is not using

        :return: The unused_permissions of this DomainOrganizationRoleUpdate.
        :rtype: list[str]
        """
        return self._unused_permissions

    @unused_permissions.setter
    def unused_permissions(self, unused_permissions):
        """
        Sets the unused_permissions of this DomainOrganizationRoleUpdate.
        A collection of the permissions the role is not using

        :param unused_permissions: The unused_permissions of this DomainOrganizationRoleUpdate.
        :type: list[str]
        """
        
        self._unused_permissions = unused_permissions

    @property
    def permission_policies(self):
        """
        Gets the permission_policies of this DomainOrganizationRoleUpdate.


        :return: The permission_policies of this DomainOrganizationRoleUpdate.
        :rtype: list[DomainPermissionPolicy]
        """
        return self._permission_policies

    @permission_policies.setter
    def permission_policies(self, permission_policies):
        """
        Sets the permission_policies of this DomainOrganizationRoleUpdate.


        :param permission_policies: The permission_policies of this DomainOrganizationRoleUpdate.
        :type: list[DomainPermissionPolicy]
        """
        
        self._permission_policies = permission_policies

    @property
    def user_count(self):
        """
        Gets the user_count of this DomainOrganizationRoleUpdate.


        :return: The user_count of this DomainOrganizationRoleUpdate.
        :rtype: int
        """
        return self._user_count

    @user_count.setter
    def user_count(self, user_count):
        """
        Sets the user_count of this DomainOrganizationRoleUpdate.


        :param user_count: The user_count of this DomainOrganizationRoleUpdate.
        :type: int
        """
        
        self._user_count = user_count

    @property
    def role_needs_update(self):
        """
        Gets the role_needs_update of this DomainOrganizationRoleUpdate.
        Optional unless patch operation.

        :return: The role_needs_update of this DomainOrganizationRoleUpdate.
        :rtype: bool
        """
        return self._role_needs_update

    @role_needs_update.setter
    def role_needs_update(self, role_needs_update):
        """
        Sets the role_needs_update of this DomainOrganizationRoleUpdate.
        Optional unless patch operation.

        :param role_needs_update: The role_needs_update of this DomainOrganizationRoleUpdate.
        :type: bool
        """
        
        self._role_needs_update = role_needs_update

    @property
    def default(self):
        """
        Gets the default of this DomainOrganizationRoleUpdate.


        :return: The default of this DomainOrganizationRoleUpdate.
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """
        Sets the default of this DomainOrganizationRoleUpdate.


        :param default: The default of this DomainOrganizationRoleUpdate.
        :type: bool
        """
        
        self._default = default

    @property
    def base(self):
        """
        Gets the base of this DomainOrganizationRoleUpdate.


        :return: The base of this DomainOrganizationRoleUpdate.
        :rtype: bool
        """
        return self._base

    @base.setter
    def base(self, base):
        """
        Sets the base of this DomainOrganizationRoleUpdate.


        :param base: The base of this DomainOrganizationRoleUpdate.
        :type: bool
        """
        
        self._base = base

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DomainOrganizationRoleUpdate.
        The URI for this object

        :return: The self_uri of this DomainOrganizationRoleUpdate.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DomainOrganizationRoleUpdate.
        The URI for this object

        :param self_uri: The self_uri of this DomainOrganizationRoleUpdate.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class TwitterIntegrationRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        TwitterIntegrationRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'access_token_key': 'str',
            'access_token_secret': 'str',
            'consumer_key': 'str',
            'consumer_secret': 'str',
            'tier': 'str',
            'env_name': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'access_token_key': 'accessTokenKey',
            'access_token_secret': 'accessTokenSecret',
            'consumer_key': 'consumerKey',
            'consumer_secret': 'consumerSecret',
            'tier': 'tier',
            'env_name': 'envName',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._access_token_key = None
        self._access_token_secret = None
        self._consumer_key = None
        self._consumer_secret = None
        self._tier = None
        self._env_name = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this TwitterIntegrationRequest.
        The globally unique identifier for the object.

        :return: The id of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TwitterIntegrationRequest.
        The globally unique identifier for the object.

        :param id: The id of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this TwitterIntegrationRequest.
        The name of the Twitter Integration

        :return: The name of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this TwitterIntegrationRequest.
        The name of the Twitter Integration

        :param name: The name of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._name = name

    @property
    def access_token_key(self):
        """
        Gets the access_token_key of this TwitterIntegrationRequest.
        The Access Token Key from Twitter messenger

        :return: The access_token_key of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._access_token_key

    @access_token_key.setter
    def access_token_key(self, access_token_key):
        """
        Sets the access_token_key of this TwitterIntegrationRequest.
        The Access Token Key from Twitter messenger

        :param access_token_key: The access_token_key of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._access_token_key = access_token_key

    @property
    def access_token_secret(self):
        """
        Gets the access_token_secret of this TwitterIntegrationRequest.
        The Access Token Secret from Twitter messenger

        :return: The access_token_secret of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._access_token_secret

    @access_token_secret.setter
    def access_token_secret(self, access_token_secret):
        """
        Sets the access_token_secret of this TwitterIntegrationRequest.
        The Access Token Secret from Twitter messenger

        :param access_token_secret: The access_token_secret of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._access_token_secret = access_token_secret

    @property
    def consumer_key(self):
        """
        Gets the consumer_key of this TwitterIntegrationRequest.
        The Consumer Key from Twitter messenger

        :return: The consumer_key of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._consumer_key

    @consumer_key.setter
    def consumer_key(self, consumer_key):
        """
        Sets the consumer_key of this TwitterIntegrationRequest.
        The Consumer Key from Twitter messenger

        :param consumer_key: The consumer_key of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._consumer_key = consumer_key

    @property
    def consumer_secret(self):
        """
        Gets the consumer_secret of this TwitterIntegrationRequest.
        The Consumer Secret from Twitter messenger

        :return: The consumer_secret of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._consumer_secret

    @consumer_secret.setter
    def consumer_secret(self, consumer_secret):
        """
        Sets the consumer_secret of this TwitterIntegrationRequest.
        The Consumer Secret from Twitter messenger

        :param consumer_secret: The consumer_secret of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._consumer_secret = consumer_secret

    @property
    def tier(self):
        """
        Gets the tier of this TwitterIntegrationRequest.
        The type of twitter account to be used for the integration

        :return: The tier of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._tier

    @tier.setter
    def tier(self, tier):
        """
        Sets the tier of this TwitterIntegrationRequest.
        The type of twitter account to be used for the integration

        :param tier: The tier of this TwitterIntegrationRequest.
        :type: str
        """
        allowed_values = ["premium", "enterprise"]
        if tier.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for tier -> " + tier)
            self._tier = "outdated_sdk_version"
        else:
            self._tier = tier

    @property
    def env_name(self):
        """
        Gets the env_name of this TwitterIntegrationRequest.
        The Twitter environment name, e.g.: env-beta (required for premium tier)

        :return: The env_name of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._env_name

    @env_name.setter
    def env_name(self, env_name):
        """
        Sets the env_name of this TwitterIntegrationRequest.
        The Twitter environment name, e.g.: env-beta (required for premium tier)

        :param env_name: The env_name of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._env_name = env_name

    @property
    def self_uri(self):
        """
        Gets the self_uri of this TwitterIntegrationRequest.
        The URI for this object

        :return: The self_uri of this TwitterIntegrationRequest.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this TwitterIntegrationRequest.
        The URI for this object

        :param self_uri: The self_uri of this TwitterIntegrationRequest.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BatchDownloadJobResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BatchDownloadJobResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'conversation_id': 'str',
            'recording_id': 'str',
            'result_url': 'str',
            'content_type': 'str',
            'error_msg': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'conversation_id': 'conversationId',
            'recording_id': 'recordingId',
            'result_url': 'resultUrl',
            'content_type': 'contentType',
            'error_msg': 'errorMsg',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._conversation_id = None
        self._recording_id = None
        self._result_url = None
        self._content_type = None
        self._error_msg = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this BatchDownloadJobResult.
        The globally unique identifier for the object.

        :return: The id of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BatchDownloadJobResult.
        The globally unique identifier for the object.

        :param id: The id of this BatchDownloadJobResult.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this BatchDownloadJobResult.


        :return: The name of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this BatchDownloadJobResult.


        :param name: The name of this BatchDownloadJobResult.
        :type: str
        """
        
        self._name = name

    @property
    def conversation_id(self):
        """
        Gets the conversation_id of this BatchDownloadJobResult.
        Conversation id of the result

        :return: The conversation_id of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, conversation_id):
        """
        Sets the conversation_id of this BatchDownloadJobResult.
        Conversation id of the result

        :param conversation_id: The conversation_id of this BatchDownloadJobResult.
        :type: str
        """
        
        self._conversation_id = conversation_id

    @property
    def recording_id(self):
        """
        Gets the recording_id of this BatchDownloadJobResult.
        Recording id of the result

        :return: The recording_id of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._recording_id

    @recording_id.setter
    def recording_id(self, recording_id):
        """
        Sets the recording_id of this BatchDownloadJobResult.
        Recording id of the result

        :param recording_id: The recording_id of this BatchDownloadJobResult.
        :type: str
        """
        
        self._recording_id = recording_id

    @property
    def result_url(self):
        """
        Gets the result_url of this BatchDownloadJobResult.
        URL of results... HTTP GET from this location to download results for this item

        :return: The result_url of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._result_url

    @result_url.setter
    def result_url(self, result_url):
        """
        Sets the result_url of this BatchDownloadJobResult.
        URL of results... HTTP GET from this location to download results for this item

        :param result_url: The result_url of this BatchDownloadJobResult.
        :type: str
        """
        
        self._result_url = result_url

    @property
    def content_type(self):
        """
        Gets the content_type of this BatchDownloadJobResult.
        Content type of this result

        :return: The content_type of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this BatchDownloadJobResult.
        Content type of this result

        :param content_type: The content_type of this BatchDownloadJobResult.
        :type: str
        """
        
        self._content_type = content_type

    @property
    def error_msg(self):
        """
        Gets the error_msg of this BatchDownloadJobResult.
        An error message, in case of failed processing will indicate the cause of the failure

        :return: The error_msg of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        """
        Sets the error_msg of this BatchDownloadJobResult.
        An error message, in case of failed processing will indicate the cause of the failure

        :param error_msg: The error_msg of this BatchDownloadJobResult.
        :type: str
        """
        
        self._error_msg = error_msg

    @property
    def self_uri(self):
        """
        Gets the self_uri of this BatchDownloadJobResult.
        The URI for this object

        :return: The self_uri of this BatchDownloadJobResult.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this BatchDownloadJobResult.
        The URI for this object

        :param self_uri: The self_uri of this BatchDownloadJobResult.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ScheduleGroup(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ScheduleGroup - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'version': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'modified_by': 'str',
            'created_by': 'str',
            'state': 'str',
            'modified_by_app': 'str',
            'created_by_app': 'str',
            'time_zone': 'str',
            'open_schedules': 'list[DomainEntityRef]',
            'closed_schedules': 'list[DomainEntityRef]',
            'holiday_schedules': 'list[DomainEntityRef]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'version': 'version',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'modified_by': 'modifiedBy',
            'created_by': 'createdBy',
            'state': 'state',
            'modified_by_app': 'modifiedByApp',
            'created_by_app': 'createdByApp',
            'time_zone': 'timeZone',
            'open_schedules': 'openSchedules',
            'closed_schedules': 'closedSchedules',
            'holiday_schedules': 'holidaySchedules',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._description = None
        self._version = None
        self._date_created = None
        self._date_modified = None
        self._modified_by = None
        self._created_by = None
        self._state = None
        self._modified_by_app = None
        self._created_by_app = None
        self._time_zone = None
        self._open_schedules = None
        self._closed_schedules = None
        self._holiday_schedules = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this ScheduleGroup.
        The globally unique identifier for the object.

        :return: The id of this ScheduleGroup.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ScheduleGroup.
        The globally unique identifier for the object.

        :param id: The id of this ScheduleGroup.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ScheduleGroup.
        The name of the entity.

        :return: The name of this ScheduleGroup.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ScheduleGroup.
        The name of the entity.

        :param name: The name of this ScheduleGroup.
        :type: str
        """
        
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ScheduleGroup.
        The resource's description.

        :return: The description of this ScheduleGroup.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ScheduleGroup.
        The resource's description.

        :param description: The description of this ScheduleGroup.
        :type: str
        """
        
        self._description = description

    @property
    def version(self):
        """
        Gets the version of this ScheduleGroup.
        The current version of the resource.

        :return: The version of this ScheduleGroup.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ScheduleGroup.
        The current version of the resource.

        :param version: The version of this ScheduleGroup.
        :type: int
        """
        
        self._version = version

    @property
    def date_created(self):
        """
        Gets the date_created of this ScheduleGroup.
        The date the resource was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_created of this ScheduleGroup.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this ScheduleGroup.
        The date the resource was created. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_created: The date_created of this ScheduleGroup.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this ScheduleGroup.
        The date of the last modification to the resource. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_modified of this ScheduleGroup.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this ScheduleGroup.
        The date of the last modification to the resource. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_modified: The date_modified of this ScheduleGroup.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def modified_by(self):
        """
        Gets the modified_by of this ScheduleGroup.
        The ID of the user that last modified the resource.

        :return: The modified_by of this ScheduleGroup.
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """
        Sets the modified_by of this ScheduleGroup.
        The ID of the user that last modified the resource.

        :param modified_by: The modified_by of this ScheduleGroup.
        :type: str
        """
        
        self._modified_by = modified_by

    @property
    def created_by(self):
        """
        Gets the created_by of this ScheduleGroup.
        The ID of the user that created the resource.

        :return: The created_by of this ScheduleGroup.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this ScheduleGroup.
        The ID of the user that created the resource.

        :param created_by: The created_by of this ScheduleGroup.
        :type: str
        """
        
        self._created_by = created_by

    @property
    def state(self):
        """
        Gets the state of this ScheduleGroup.
        Indicates if the resource is active, inactive, or deleted.

        :return: The state of this ScheduleGroup.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this ScheduleGroup.
        Indicates if the resource is active, inactive, or deleted.

        :param state: The state of this ScheduleGroup.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def modified_by_app(self):
        """
        Gets the modified_by_app of this ScheduleGroup.
        The application that last modified the resource.

        :return: The modified_by_app of this ScheduleGroup.
        :rtype: str
        """
        return self._modified_by_app

    @modified_by_app.setter
    def modified_by_app(self, modified_by_app):
        """
        Sets the modified_by_app of this ScheduleGroup.
        The application that last modified the resource.

        :param modified_by_app: The modified_by_app of this ScheduleGroup.
        :type: str
        """
        
        self._modified_by_app = modified_by_app

    @property
    def created_by_app(self):
        """
        Gets the created_by_app of this ScheduleGroup.
        The application that created the resource.

        :return: The created_by_app of this ScheduleGroup.
        :rtype: str
        """
        return self._created_by_app

    @created_by_app.setter
    def created_by_app(self, created_by_app):
        """
        Sets the created_by_app of this ScheduleGroup.
        The application that created the resource.

        :param created_by_app: The created_by_app of this ScheduleGroup.
        :type: str
        """
        
        self._created_by_app = created_by_app

    @property
    def time_zone(self):
        """
        Gets the time_zone of this ScheduleGroup.
        The timezone the schedules are a part of.  This is not a schedule property to allow a schedule to be used in multiple timezones.

        :return: The time_zone of this ScheduleGroup.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """
        Sets the time_zone of this ScheduleGroup.
        The timezone the schedules are a part of.  This is not a schedule property to allow a schedule to be used in multiple timezones.

        :param time_zone: The time_zone of this ScheduleGroup.
        :type: str
        """
        
        self._time_zone = time_zone

    @property
    def open_schedules(self):
        """
        Gets the open_schedules of this ScheduleGroup.
        The schedules defining the hours an organization is open.

        :return: The open_schedules of this ScheduleGroup.
        :rtype: list[DomainEntityRef]
        """
        return self._open_schedules

    @open_schedules.setter
    def open_schedules(self, open_schedules):
        """
        Sets the open_schedules of this ScheduleGroup.
        The schedules defining the hours an organization is open.

        :param open_schedules: The open_schedules of this ScheduleGroup.
        :type: list[DomainEntityRef]
        """
        
        self._open_schedules = open_schedules

    @property
    def closed_schedules(self):
        """
        Gets the closed_schedules of this ScheduleGroup.
        The schedules defining the hours an organization is closed.

        :return: The closed_schedules of this ScheduleGroup.
        :rtype: list[DomainEntityRef]
        """
        return self._closed_schedules

    @closed_schedules.setter
    def closed_schedules(self, closed_schedules):
        """
        Sets the closed_schedules of this ScheduleGroup.
        The schedules defining the hours an organization is closed.

        :param closed_schedules: The closed_schedules of this ScheduleGroup.
        :type: list[DomainEntityRef]
        """
        
        self._closed_schedules = closed_schedules

    @property
    def holiday_schedules(self):
        """
        Gets the holiday_schedules of this ScheduleGroup.
        The schedules defining the hours an organization is closed for the holidays.

        :return: The holiday_schedules of this ScheduleGroup.
        :rtype: list[DomainEntityRef]
        """
        return self._holiday_schedules

    @holiday_schedules.setter
    def holiday_schedules(self, holiday_schedules):
        """
        Sets the holiday_schedules of this ScheduleGroup.
        The schedules defining the hours an organization is closed for the holidays.

        :param holiday_schedules: The holiday_schedules of this ScheduleGroup.
        :type: list[DomainEntityRef]
        """
        
        self._holiday_schedules = holiday_schedules

    @property
    def self_uri(self):
        """
        Gets the self_uri of this ScheduleGroup.
        The URI for this object

        :return: The self_uri of this ScheduleGroup.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this ScheduleGroup.
        The URI for this object

        :param self_uri: The self_uri of this ScheduleGroup.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
OrganizationApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class OrganizationApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def get_fieldconfig(self, type, **kwargs):
        """
        Fetch field config for an entity type
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_fieldconfig(type, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str type: Field type (required)
        :return: FieldConfig
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['type']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_fieldconfig" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'type' is set
        if ('type' not in params) or (params['type'] is None):
            raise ValueError("Missing the required parameter `type` when calling `get_fieldconfig`")


        resource_path = '/api/v2/fieldconfig'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'type' in params:
            query_params['type'] = params['type']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='FieldConfig',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_organizations_embeddedintegration(self, **kwargs):
        """
        Get the list of domains that will be allowed to embed PureCloud applications
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_organizations_embeddedintegration(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: EmbeddedIntegration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_organizations_embeddedintegration" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/organizations/embeddedintegration'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='EmbeddedIntegration',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_organizations_ipaddressauthentication(self, **kwargs):
        """
        Get organization IP address whitelist settings
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_organizations_ipaddressauthentication(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: IpAddressAuthentication
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_organizations_ipaddressauthentication" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/organizations/ipaddressauthentication'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='IpAddressAuthentication',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_organizations_me(self, **kwargs):
        """
        Get organization.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_organizations_me(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_organizations_me" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/organizations/me'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Organization',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_organizations_whitelist(self, **kwargs):
        """
        Use PUT /api/v2/organizations/embeddedintegration instead
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_organizations_whitelist(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :return: OrgWhitelistSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_organizations_whitelist" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/organizations/whitelist'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrgWhitelistSettings',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def patch_organizations_feature(self, feature_name, enabled, **kwargs):
        """
        Update organization
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.patch_organizations_feature(feature_name, enabled, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str feature_name: Organization feature (required)
        :param FeatureState enabled: New state of feature (required)
        :return: OrganizationFeatures
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['feature_name', 'enabled']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method patch_organizations_feature" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'feature_name' is set
        if ('feature_name' not in params) or (params['feature_name'] is None):
            raise ValueError("Missing the required parameter `feature_name` when calling `patch_organizations_feature`")
        # verify the required parameter 'enabled' is set
        if ('enabled' not in params) or (params['enabled'] is None):
            raise ValueError("Missing the required parameter `enabled` when calling `patch_organizations_feature`")


        resource_path = '/api/v2/organizations/features/{featureName}'.replace('{format}', 'json')
        path_params = {}
        if 'feature_name' in params:
            path_params['featureName'] = params['feature_name']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'enabled' in params:
            body_params = params['enabled']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PATCH',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrganizationFeatures',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_organizations_embeddedintegration(self, body, **kwargs):
        """
        Update the list of domains that will be allowed to embed PureCloud applications
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_organizations_embeddedintegration(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param EmbeddedIntegration body: Whitelist settings (required)
        :return: EmbeddedIntegration
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_organizations_embeddedintegration" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_organizations_embeddedintegration`")


        resource_path = '/api/v2/organizations/embeddedintegration'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='EmbeddedIntegration',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_organizations_ipaddressauthentication(self, body, **kwargs):
        """
        Update organization IP address whitelist settings
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_organizations_ipaddressauthentication(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param IpAddressAuthentication body: IP address Whitelist settings (required)
        :return: IpAddressAuthentication
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_organizations_ipaddressauthentication" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_organizations_ipaddressauthentication`")


        resource_path = '/api/v2/organizations/ipaddressauthentication'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='IpAddressAuthentication',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_organizations_me(self, **kwargs):
        """
        Update organization.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_organizations_me(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Organization body: Organization
        :return: Organization
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_organizations_me" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/organizations/me'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Organization',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_organizations_whitelist(self, body, **kwargs):
        """
        Use PUT /api/v2/organizations/embeddedintegration instead
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_organizations_whitelist(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param OrgWhitelistSettings body: Whitelist settings (required)
        :return: OrgWhitelistSettings
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_organizations_whitelist" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `put_organizations_whitelist`")


        resource_path = '/api/v2/organizations/whitelist'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='OrgWhitelistSettings',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class MailFromResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MailFromResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'status': 'str',
            'records': 'list[Record]',
            'mail_from_domain': 'str'
        }

        self.attribute_map = {
            'status': 'status',
            'records': 'records',
            'mail_from_domain': 'mailFromDomain'
        }

        self._status = None
        self._records = None
        self._mail_from_domain = None

    @property
    def status(self):
        """
        Gets the status of this MailFromResult.
        The verification status.

        :return: The status of this MailFromResult.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this MailFromResult.
        The verification status.

        :param status: The status of this MailFromResult.
        :type: str
        """
        allowed_values = ["FAILED", "PENDING", "VERIFIED", "UNKNOWN"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def records(self):
        """
        Gets the records of this MailFromResult.
        The list of DNS records that pertain that need to exist for verification.

        :return: The records of this MailFromResult.
        :rtype: list[Record]
        """
        return self._records

    @records.setter
    def records(self, records):
        """
        Sets the records of this MailFromResult.
        The list of DNS records that pertain that need to exist for verification.

        :param records: The records of this MailFromResult.
        :type: list[Record]
        """
        
        self._records = records

    @property
    def mail_from_domain(self):
        """
        Gets the mail_from_domain of this MailFromResult.
        The custom MAIL FROM domain.

        :return: The mail_from_domain of this MailFromResult.
        :rtype: str
        """
        return self._mail_from_domain

    @mail_from_domain.setter
    def mail_from_domain(self, mail_from_domain):
        """
        Sets the mail_from_domain of this MailFromResult.
        The custom MAIL FROM domain.

        :param mail_from_domain: The mail_from_domain of this MailFromResult.
        :type: str
        """
        
        self._mail_from_domain = mail_from_domain

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class MessageData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        MessageData - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'provider_message_id': 'str',
            'timestamp': 'datetime',
            'from_address': 'str',
            'to_address': 'str',
            'direction': 'str',
            'messenger_type': 'str',
            'text_body': 'str',
            'status': 'str',
            'media': 'list[MessageMedia]',
            'stickers': 'list[MessageSticker]',
            'created_by': 'User',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'provider_message_id': 'providerMessageId',
            'timestamp': 'timestamp',
            'from_address': 'fromAddress',
            'to_address': 'toAddress',
            'direction': 'direction',
            'messenger_type': 'messengerType',
            'text_body': 'textBody',
            'status': 'status',
            'media': 'media',
            'stickers': 'stickers',
            'created_by': 'createdBy',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._provider_message_id = None
        self._timestamp = None
        self._from_address = None
        self._to_address = None
        self._direction = None
        self._messenger_type = None
        self._text_body = None
        self._status = None
        self._media = None
        self._stickers = None
        self._created_by = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this MessageData.
        The globally unique identifier for the object.

        :return: The id of this MessageData.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MessageData.
        The globally unique identifier for the object.

        :param id: The id of this MessageData.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this MessageData.


        :return: The name of this MessageData.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this MessageData.


        :param name: The name of this MessageData.
        :type: str
        """
        
        self._name = name

    @property
    def provider_message_id(self):
        """
        Gets the provider_message_id of this MessageData.
        The unique identifier of the message from provider

        :return: The provider_message_id of this MessageData.
        :rtype: str
        """
        return self._provider_message_id

    @provider_message_id.setter
    def provider_message_id(self, provider_message_id):
        """
        Sets the provider_message_id of this MessageData.
        The unique identifier of the message from provider

        :param provider_message_id: The provider_message_id of this MessageData.
        :type: str
        """
        
        self._provider_message_id = provider_message_id

    @property
    def timestamp(self):
        """
        Gets the timestamp of this MessageData.
        The time when the message was received or sent. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The timestamp of this MessageData.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this MessageData.
        The time when the message was received or sent. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param timestamp: The timestamp of this MessageData.
        :type: datetime
        """
        
        self._timestamp = timestamp

    @property
    def from_address(self):
        """
        Gets the from_address of this MessageData.
        The sender of the text message.

        :return: The from_address of this MessageData.
        :rtype: str
        """
        return self._from_address

    @from_address.setter
    def from_address(self, from_address):
        """
        Sets the from_address of this MessageData.
        The sender of the text message.

        :param from_address: The from_address of this MessageData.
        :type: str
        """
        
        self._from_address = from_address

    @property
    def to_address(self):
        """
        Gets the to_address of this MessageData.
        The recipient of the text message.

        :return: The to_address of this MessageData.
        :rtype: str
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """
        Sets the to_address of this MessageData.
        The recipient of the text message.

        :param to_address: The to_address of this MessageData.
        :type: str
        """
        
        self._to_address = to_address

    @property
    def direction(self):
        """
        Gets the direction of this MessageData.
        The direction of the message.

        :return: The direction of this MessageData.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this MessageData.
        The direction of the message.

        :param direction: The direction of this MessageData.
        :type: str
        """
        allowed_values = ["inbound", "outbound"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def messenger_type(self):
        """
        Gets the messenger_type of this MessageData.
        Type of text messenger.

        :return: The messenger_type of this MessageData.
        :rtype: str
        """
        return self._messenger_type

    @messenger_type.setter
    def messenger_type(self, messenger_type):
        """
        Sets the messenger_type of this MessageData.
        Type of text messenger.

        :param messenger_type: The messenger_type of this MessageData.
        :type: str
        """
        allowed_values = ["sms", "facebook", "twitter", "line", "whatsapp", "webmessaging", "open"]
        if messenger_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for messenger_type -> " + messenger_type)
            self._messenger_type = "outdated_sdk_version"
        else:
            self._messenger_type = messenger_type

    @property
    def text_body(self):
        """
        Gets the text_body of this MessageData.
        The body of the text message.

        :return: The text_body of this MessageData.
        :rtype: str
        """
        return self._text_body

    @text_body.setter
    def text_body(self, text_body):
        """
        Sets the text_body of this MessageData.
        The body of the text message.

        :param text_body: The text_body of this MessageData.
        :type: str
        """
        
        self._text_body = text_body

    @property
    def status(self):
        """
        Gets the status of this MessageData.
        The status of the message.

        :return: The status of this MessageData.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this MessageData.
        The status of the message.

        :param status: The status of this MessageData.
        :type: str
        """
        allowed_values = ["queued", "sent", "failed", "received", "delivery-success", "delivery-failed", "read"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def media(self):
        """
        Gets the media of this MessageData.
        The media details associated to a message.

        :return: The media of this MessageData.
        :rtype: list[MessageMedia]
        """
        return self._media

    @media.setter
    def media(self, media):
        """
        Sets the media of this MessageData.
        The media details associated to a message.

        :param media: The media of this MessageData.
        :type: list[MessageMedia]
        """
        
        self._media = media

    @property
    def stickers(self):
        """
        Gets the stickers of this MessageData.
        The sticker details associated to a message.

        :return: The stickers of this MessageData.
        :rtype: list[MessageSticker]
        """
        return self._stickers

    @stickers.setter
    def stickers(self, stickers):
        """
        Sets the stickers of this MessageData.
        The sticker details associated to a message.

        :param stickers: The stickers of this MessageData.
        :type: list[MessageSticker]
        """
        
        self._stickers = stickers

    @property
    def created_by(self):
        """
        Gets the created_by of this MessageData.
        User who sent this message.

        :return: The created_by of this MessageData.
        :rtype: User
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this MessageData.
        User who sent this message.

        :param created_by: The created_by of this MessageData.
        :type: User
        """
        
        self._created_by = created_by

    @property
    def self_uri(self):
        """
        Gets the self_uri of this MessageData.
        The URI for this object

        :return: The self_uri of this MessageData.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this MessageData.
        The URI for this object

        :param self_uri: The self_uri of this MessageData.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AuditQueryExecutionStatusResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AuditQueryExecutionStatusResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'start_date': 'datetime',
            'interval': 'str',
            'service_name': 'str',
            'filters': 'list[AuditQueryFilter]',
            'sort': 'list[AuditQuerySort]'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'start_date': 'startDate',
            'interval': 'interval',
            'service_name': 'serviceName',
            'filters': 'filters',
            'sort': 'sort'
        }

        self._id = None
        self._state = None
        self._start_date = None
        self._interval = None
        self._service_name = None
        self._filters = None
        self._sort = None

    @property
    def id(self):
        """
        Gets the id of this AuditQueryExecutionStatusResponse.
        Id of the audit query execution request.

        :return: The id of this AuditQueryExecutionStatusResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AuditQueryExecutionStatusResponse.
        Id of the audit query execution request.

        :param id: The id of this AuditQueryExecutionStatusResponse.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this AuditQueryExecutionStatusResponse.
        Status of the audit query execution request.

        :return: The state of this AuditQueryExecutionStatusResponse.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this AuditQueryExecutionStatusResponse.
        Status of the audit query execution request.

        :param state: The state of this AuditQueryExecutionStatusResponse.
        :type: str
        """
        allowed_values = ["Queued", "Running", "Succeeded", "Failed", "Cancelled"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def start_date(self):
        """
        Gets the start_date of this AuditQueryExecutionStatusResponse.
        Start date and time of the audit query execution. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_date of this AuditQueryExecutionStatusResponse.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this AuditQueryExecutionStatusResponse.
        Start date and time of the audit query execution. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_date: The start_date of this AuditQueryExecutionStatusResponse.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def interval(self):
        """
        Gets the interval of this AuditQueryExecutionStatusResponse.
        Interval for the audit query. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :return: The interval of this AuditQueryExecutionStatusResponse.
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """
        Sets the interval of this AuditQueryExecutionStatusResponse.
        Interval for the audit query. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :param interval: The interval of this AuditQueryExecutionStatusResponse.
        :type: str
        """
        
        self._interval = interval

    @property
    def service_name(self):
        """
        Gets the service_name of this AuditQueryExecutionStatusResponse.
        Service name for the audit query.

        :return: The service_name of this AuditQueryExecutionStatusResponse.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this AuditQueryExecutionStatusResponse.
        Service name for the audit query.

        :param service_name: The service_name of this AuditQueryExecutionStatusResponse.
        :type: str
        """
        allowed_values = ["Architect", "ContactCenter", "ContentManagement", "PeoplePermissions", "Presence", "Quality", "LanguageUnderstanding", "TopicsDefinitions", "PredictiveEngagement", "WorkforceManagement", "Triggers", "ResponseManagement", "Groups", "Telephony", "Outbound", "SpeechAndTextAnalytics", "Routing"]
        if service_name.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for service_name -> " + service_name)
            self._service_name = "outdated_sdk_version"
        else:
            self._service_name = service_name

    @property
    def filters(self):
        """
        Gets the filters of this AuditQueryExecutionStatusResponse.
        Filters for the audit query.

        :return: The filters of this AuditQueryExecutionStatusResponse.
        :rtype: list[AuditQueryFilter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """
        Sets the filters of this AuditQueryExecutionStatusResponse.
        Filters for the audit query.

        :param filters: The filters of this AuditQueryExecutionStatusResponse.
        :type: list[AuditQueryFilter]
        """
        
        self._filters = filters

    @property
    def sort(self):
        """
        Gets the sort of this AuditQueryExecutionStatusResponse.
        Sort parameter for the audit query.

        :return: The sort of this AuditQueryExecutionStatusResponse.
        :rtype: list[AuditQuerySort]
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """
        Sets the sort of this AuditQueryExecutionStatusResponse.
        Sort parameter for the audit query.

        :param sort: The sort of this AuditQueryExecutionStatusResponse.
        :type: list[AuditQuerySort]
        """
        
        self._sort = sort

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AvailableTopic(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AvailableTopic - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'description': 'str',
            'id': 'str',
            'permission_details': 'list[PermissionDetails]',
            'requires_permissions': 'list[str]',
            'requires_division_permissions': 'bool',
            'enforced': 'bool',
            'visibility': 'str',
            'schema': 'dict(str, object)',
            'requires_current_user': 'bool',
            'requires_current_user_or_permission': 'bool',
            'transports': 'list[str]',
            'public_api_template_uri_paths': 'list[str]'
        }

        self.attribute_map = {
            'description': 'description',
            'id': 'id',
            'permission_details': 'permissionDetails',
            'requires_permissions': 'requiresPermissions',
            'requires_division_permissions': 'requiresDivisionPermissions',
            'enforced': 'enforced',
            'visibility': 'visibility',
            'schema': 'schema',
            'requires_current_user': 'requiresCurrentUser',
            'requires_current_user_or_permission': 'requiresCurrentUserOrPermission',
            'transports': 'transports',
            'public_api_template_uri_paths': 'publicApiTemplateUriPaths'
        }

        self._description = None
        self._id = None
        self._permission_details = None
        self._requires_permissions = None
        self._requires_division_permissions = None
        self._enforced = None
        self._visibility = None
        self._schema = None
        self._requires_current_user = None
        self._requires_current_user_or_permission = None
        self._transports = None
        self._public_api_template_uri_paths = None

    @property
    def description(self):
        """
        Gets the description of this AvailableTopic.


        :return: The description of this AvailableTopic.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this AvailableTopic.


        :param description: The description of this AvailableTopic.
        :type: str
        """
        
        self._description = description

    @property
    def id(self):
        """
        Gets the id of this AvailableTopic.


        :return: The id of this AvailableTopic.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AvailableTopic.


        :param id: The id of this AvailableTopic.
        :type: str
        """
        
        self._id = id

    @property
    def permission_details(self):
        """
        Gets the permission_details of this AvailableTopic.
        Full detailed permissions required to subscribe to the topic

        :return: The permission_details of this AvailableTopic.
        :rtype: list[PermissionDetails]
        """
        return self._permission_details

    @permission_details.setter
    def permission_details(self, permission_details):
        """
        Sets the permission_details of this AvailableTopic.
        Full detailed permissions required to subscribe to the topic

        :param permission_details: The permission_details of this AvailableTopic.
        :type: list[PermissionDetails]
        """
        
        self._permission_details = permission_details

    @property
    def requires_permissions(self):
        """
        Gets the requires_permissions of this AvailableTopic.
        Permissions required to subscribe to the topic

        :return: The requires_permissions of this AvailableTopic.
        :rtype: list[str]
        """
        return self._requires_permissions

    @requires_permissions.setter
    def requires_permissions(self, requires_permissions):
        """
        Sets the requires_permissions of this AvailableTopic.
        Permissions required to subscribe to the topic

        :param requires_permissions: The requires_permissions of this AvailableTopic.
        :type: list[str]
        """
        
        self._requires_permissions = requires_permissions

    @property
    def requires_division_permissions(self):
        """
        Gets the requires_division_permissions of this AvailableTopic.
        True if the subscribing user must belong to the same division as the topic object ID

        :return: The requires_division_permissions of this AvailableTopic.
        :rtype: bool
        """
        return self._requires_division_permissions

    @requires_division_permissions.setter
    def requires_division_permissions(self, requires_division_permissions):
        """
        Sets the requires_division_permissions of this AvailableTopic.
        True if the subscribing user must belong to the same division as the topic object ID

        :param requires_division_permissions: The requires_division_permissions of this AvailableTopic.
        :type: bool
        """
        
        self._requires_division_permissions = requires_division_permissions

    @property
    def enforced(self):
        """
        Gets the enforced of this AvailableTopic.
        Whether or not the permissions on this topic are enforced

        :return: The enforced of this AvailableTopic.
        :rtype: bool
        """
        return self._enforced

    @enforced.setter
    def enforced(self, enforced):
        """
        Sets the enforced of this AvailableTopic.
        Whether or not the permissions on this topic are enforced

        :param enforced: The enforced of this AvailableTopic.
        :type: bool
        """
        
        self._enforced = enforced

    @property
    def visibility(self):
        """
        Gets the visibility of this AvailableTopic.
        Visibility of this topic (Public or Preview)

        :return: The visibility of this AvailableTopic.
        :rtype: str
        """
        return self._visibility

    @visibility.setter
    def visibility(self, visibility):
        """
        Sets the visibility of this AvailableTopic.
        Visibility of this topic (Public or Preview)

        :param visibility: The visibility of this AvailableTopic.
        :type: str
        """
        allowed_values = ["Public", "Preview"]
        if visibility.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for visibility -> " + visibility)
            self._visibility = "outdated_sdk_version"
        else:
            self._visibility = visibility

    @property
    def schema(self):
        """
        Gets the schema of this AvailableTopic.


        :return: The schema of this AvailableTopic.
        :rtype: dict(str, object)
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """
        Sets the schema of this AvailableTopic.


        :param schema: The schema of this AvailableTopic.
        :type: dict(str, object)
        """
        
        self._schema = schema

    @property
    def requires_current_user(self):
        """
        Gets the requires_current_user of this AvailableTopic.
        True if the topic user ID is required to match the subscribing user ID

        :return: The requires_current_user of this AvailableTopic.
        :rtype: bool
        """
        return self._requires_current_user

    @requires_current_user.setter
    def requires_current_user(self, requires_current_user):
        """
        Sets the requires_current_user of this AvailableTopic.
        True if the topic user ID is required to match the subscribing user ID

        :param requires_current_user: The requires_current_user of this AvailableTopic.
        :type: bool
        """
        
        self._requires_current_user = requires_current_user

    @property
    def requires_current_user_or_permission(self):
        """
        Gets the requires_current_user_or_permission of this AvailableTopic.
        True if permissions are only required when the topic user ID does not match the subscribing user ID

        :return: The requires_current_user_or_permission of this AvailableTopic.
        :rtype: bool
        """
        return self._requires_current_user_or_permission

    @requires_current_user_or_permission.setter
    def requires_current_user_or_permission(self, requires_current_user_or_permission):
        """
        Sets the requires_current_user_or_permission of this AvailableTopic.
        True if permissions are only required when the topic user ID does not match the subscribing user ID

        :param requires_current_user_or_permission: The requires_current_user_or_permission of this AvailableTopic.
        :type: bool
        """
        
        self._requires_current_user_or_permission = requires_current_user_or_permission

    @property
    def transports(self):
        """
        Gets the transports of this AvailableTopic.
        Transports that support events for the topic

        :return: The transports of this AvailableTopic.
        :rtype: list[str]
        """
        return self._transports

    @transports.setter
    def transports(self, transports):
        """
        Sets the transports of this AvailableTopic.
        Transports that support events for the topic

        :param transports: The transports of this AvailableTopic.
        :type: list[str]
        """
        
        self._transports = transports

    @property
    def public_api_template_uri_paths(self):
        """
        Gets the public_api_template_uri_paths of this AvailableTopic.


        :return: The public_api_template_uri_paths of this AvailableTopic.
        :rtype: list[str]
        """
        return self._public_api_template_uri_paths

    @public_api_template_uri_paths.setter
    def public_api_template_uri_paths(self, public_api_template_uri_paths):
        """
        Sets the public_api_template_uri_paths of this AvailableTopic.


        :param public_api_template_uri_paths: The public_api_template_uri_paths of this AvailableTopic.
        :type: list[str]
        """
        
        self._public_api_template_uri_paths = public_api_template_uri_paths

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class FlowDivisionView(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowDivisionView - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'division': 'WritableDivision',
            'type': 'str',
            'input_schema': 'JsonSchemaDocument',
            'output_schema': 'JsonSchemaDocument',
            'published_version': 'FlowVersion',
            'debug_version': 'FlowVersion',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'division': 'division',
            'type': 'type',
            'input_schema': 'inputSchema',
            'output_schema': 'outputSchema',
            'published_version': 'publishedVersion',
            'debug_version': 'debugVersion',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._division = None
        self._type = None
        self._input_schema = None
        self._output_schema = None
        self._published_version = None
        self._debug_version = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this FlowDivisionView.
        The flow identifier

        :return: The id of this FlowDivisionView.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FlowDivisionView.
        The flow identifier

        :param id: The id of this FlowDivisionView.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this FlowDivisionView.
        The flow name

        :return: The name of this FlowDivisionView.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FlowDivisionView.
        The flow name

        :param name: The name of this FlowDivisionView.
        :type: str
        """
        
        self._name = name

    @property
    def division(self):
        """
        Gets the division of this FlowDivisionView.
        The division to which this entity belongs.

        :return: The division of this FlowDivisionView.
        :rtype: WritableDivision
        """
        return self._division

    @division.setter
    def division(self, division):
        """
        Sets the division of this FlowDivisionView.
        The division to which this entity belongs.

        :param division: The division of this FlowDivisionView.
        :type: WritableDivision
        """
        
        self._division = division

    @property
    def type(self):
        """
        Gets the type of this FlowDivisionView.


        :return: The type of this FlowDivisionView.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this FlowDivisionView.


        :param type: The type of this FlowDivisionView.
        :type: str
        """
        allowed_values = ["BOT", "COMMONMODULE", "INBOUNDCALL", "INBOUNDCHAT", "INBOUNDEMAIL", "INBOUNDSHORTMESSAGE", "INQUEUECALL", "OUTBOUNDCALL", "SECURECALL", "SPEECH", "SURVEYINVITE", "WORKFLOW"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def input_schema(self):
        """
        Gets the input_schema of this FlowDivisionView.
        json schema describing the inputs for the flow

        :return: The input_schema of this FlowDivisionView.
        :rtype: JsonSchemaDocument
        """
        return self._input_schema

    @input_schema.setter
    def input_schema(self, input_schema):
        """
        Sets the input_schema of this FlowDivisionView.
        json schema describing the inputs for the flow

        :param input_schema: The input_schema of this FlowDivisionView.
        :type: JsonSchemaDocument
        """
        
        self._input_schema = input_schema

    @property
    def output_schema(self):
        """
        Gets the output_schema of this FlowDivisionView.
        json schema describing the outputs for the flow

        :return: The output_schema of this FlowDivisionView.
        :rtype: JsonSchemaDocument
        """
        return self._output_schema

    @output_schema.setter
    def output_schema(self, output_schema):
        """
        Sets the output_schema of this FlowDivisionView.
        json schema describing the outputs for the flow

        :param output_schema: The output_schema of this FlowDivisionView.
        :type: JsonSchemaDocument
        """
        
        self._output_schema = output_schema

    @property
    def published_version(self):
        """
        Gets the published_version of this FlowDivisionView.
        published version information if there is a published version

        :return: The published_version of this FlowDivisionView.
        :rtype: FlowVersion
        """
        return self._published_version

    @published_version.setter
    def published_version(self, published_version):
        """
        Sets the published_version of this FlowDivisionView.
        published version information if there is a published version

        :param published_version: The published_version of this FlowDivisionView.
        :type: FlowVersion
        """
        
        self._published_version = published_version

    @property
    def debug_version(self):
        """
        Gets the debug_version of this FlowDivisionView.
        debug version information if there is a debug version

        :return: The debug_version of this FlowDivisionView.
        :rtype: FlowVersion
        """
        return self._debug_version

    @debug_version.setter
    def debug_version(self, debug_version):
        """
        Sets the debug_version of this FlowDivisionView.
        debug version information if there is a debug version

        :param debug_version: The debug_version of this FlowDivisionView.
        :type: FlowVersion
        """
        
        self._debug_version = debug_version

    @property
    def self_uri(self):
        """
        Gets the self_uri of this FlowDivisionView.
        The URI for this object

        :return: The self_uri of this FlowDivisionView.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this FlowDivisionView.
        The URI for this object

        :param self_uri: The self_uri of this FlowDivisionView.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
GroupsApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os
import re

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class GroupsApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_group(self, group_id, **kwargs):
        """
        Delete group
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_group(group_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_id: Group ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_group" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'group_id' is set
        if ('group_id' not in params) or (params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `delete_group`")


        resource_path = '/api/v2/groups/{groupId}'.replace('{format}', 'json')
        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def delete_group_members(self, group_id, ids, **kwargs):
        """
        Remove members
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_group_members(group_id, ids, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_id: Group ID (required)
        :param str ids: Comma separated list of userIds to remove (required)
        :return: Empty
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'ids']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_group_members" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'group_id' is set
        if ('group_id' not in params) or (params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `delete_group_members`")
        # verify the required parameter 'ids' is set
        if ('ids' not in params) or (params['ids'] is None):
            raise ValueError("Missing the required parameter `ids` when calling `delete_group_members`")


        resource_path = '/api/v2/groups/{groupId}/members'.replace('{format}', 'json')
        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']

        query_params = {}
        if 'ids' in params:
            query_params['ids'] = params['ids']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Empty',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_fieldconfig(self, type, **kwargs):
        """
        Fetch field config for an entity type
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_fieldconfig(type, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str type: Field type (required)
        :return: FieldConfig
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['type']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_fieldconfig" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'type' is set
        if ('type' not in params) or (params['type'] is None):
            raise ValueError("Missing the required parameter `type` when calling `get_fieldconfig`")


        resource_path = '/api/v2/fieldconfig'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'type' in params:
            query_params['type'] = params['type']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='FieldConfig',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_group(self, group_id, **kwargs):
        """
        Get group
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_group(group_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_id: Group ID (required)
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'group_id' is set
        if ('group_id' not in params) or (params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_group`")


        resource_path = '/api/v2/groups/{groupId}'.replace('{format}', 'json')
        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Group',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_group_individuals(self, group_id, **kwargs):
        """
        Get all individuals associated with the group
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_group_individuals(group_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_id: Group ID (required)
        :return: UserEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_individuals" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'group_id' is set
        if ('group_id' not in params) or (params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_group_individuals`")


        resource_path = '/api/v2/groups/{groupId}/individuals'.replace('{format}', 'json')
        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_group_members(self, group_id, **kwargs):
        """
        Get group members, includes individuals, owners, and dynamically included people
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_group_members(group_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_id: Group ID (required)
        :param int page_size: Page size
        :param int page_number: Page number
        :param str sort_order: Ascending or descending sort order
        :param list[str] expand: Which fields, if any, to expand
        :return: UserEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'page_size', 'page_number', 'sort_order', 'expand']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_members" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'group_id' is set
        if ('group_id' not in params) or (params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_group_members`")


        resource_path = '/api/v2/groups/{groupId}/members'.replace('{format}', 'json')
        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'sort_order' in params:
            query_params['sortOrder'] = params['sort_order']
        if 'expand' in params:
            query_params['expand'] = params['expand']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='UserEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_group_profile(self, group_id, **kwargs):
        """
        Get group profile
        This api is deprecated. Use /api/v2/groups instead

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_group_profile(group_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_id: groupId (required)
        :param str fields: Comma separated fields to return.  Allowable values can be found by querying /api/v2/fieldconfig?type=group and using the key for the elements returned by the fieldList
        :return: GroupProfile
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'fields']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_group_profile" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'group_id' is set
        if ('group_id' not in params) or (params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_group_profile`")


        resource_path = '/api/v2/groups/{groupId}/profile'.replace('{format}', 'json')
        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']

        query_params = {}
        if 'fields' in params:
            query_params['fields'] = params['fields']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GroupProfile',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_groups(self, **kwargs):
        """
        Get a group list
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_groups(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: Page size
        :param int page_number: Page number
        :param list[str] id: id
        :param list[str] jabber_id: A list of jabberIds to fetch by bulk (cannot be used with the \"id\" parameter)
        :param str sort_order: Ascending or descending sort order
        :return: GroupEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number', 'id', 'jabber_id', 'sort_order']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_groups" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/groups'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'id' in params:
            query_params['id'] = params['id']
        if 'jabber_id' in params:
            query_params['jabberId'] = params['jabber_id']
        if 'sort_order' in params:
            query_params['sortOrder'] = params['sort_order']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GroupEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_groups_search(self, q64, **kwargs):
        """
        Search groups using the q64 value returned from a previous search
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_groups_search(q64, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str q64: q64 (required)
        :param list[str] expand: expand
        :return: GroupsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['q64', 'expand']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_groups_search" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'q64' is set
        if ('q64' not in params) or (params['q64'] is None):
            raise ValueError("Missing the required parameter `q64` when calling `get_groups_search`")


        resource_path = '/api/v2/groups/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'q64' in params:
            query_params['q64'] = params['q64']
        if 'expand' in params:
            query_params['expand'] = params['expand']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GroupsSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_profiles_groups(self, **kwargs):
        """
        Get group profile listing
        This api is deprecated. Use /api/v2/groups instead.

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_profiles_groups(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: Page size
        :param int page_number: Page number
        :param list[str] id: id
        :param str sort_order: Ascending or descending sort order
        :return: GroupProfileEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number', 'id', 'sort_order']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_profiles_groups" % key
                )
            params[key] = val
        del params['kwargs']



        resource_path = '/api/v2/profiles/groups'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'id' in params:
            query_params['id'] = params['id']
        if 'sort_order' in params:
            query_params['sortOrder'] = params['sort_order']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GroupProfileEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_group_members(self, group_id, body, **kwargs):
        """
        Add members
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_group_members(group_id, body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_id: Group ID (required)
        :param GroupMembersUpdate body: Add members (required)
        :return: Empty
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_group_members" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'group_id' is set
        if ('group_id' not in params) or (params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `post_group_members`")
        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_group_members`")


        resource_path = '/api/v2/groups/{groupId}/members'.replace('{format}', 'json')
        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Empty',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_groups(self, body, **kwargs):
        """
        Create a group
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_groups(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param GroupCreate body: Group (required)
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_groups" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_groups`")


        resource_path = '/api/v2/groups'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Group',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_groups_search(self, body, **kwargs):
        """
        Search groups
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_groups_search(body, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param GroupSearchRequest body: Search request options (required)
        :return: GroupsSearchResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_groups_search" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'body' is set
        if ('body' not in params) or (params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `post_groups_search`")


        resource_path = '/api/v2/groups/search'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='GroupsSearchResponse',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_group(self, group_id, **kwargs):
        """
        Update group
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_group(group_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str group_id: Group ID (required)
        :param GroupUpdate body: Group
        :return: Group
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_group" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'group_id' is set
        if ('group_id' not in params) or (params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `put_group`")


        resource_path = '/api/v2/groups/{groupId}'.replace('{format}', 'json')
        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud OAuth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Group',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuAgentScheduleHistoryResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuAgentScheduleHistoryResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'prior_published_schedules': 'list[BuScheduleReference]',
            'base_published_schedule': 'BuAgentScheduleHistoryChange',
            'dropped_changes': 'list[BuAgentScheduleHistoryDroppedChange]',
            'changes': 'list[BuAgentScheduleHistoryChange]'
        }

        self.attribute_map = {
            'prior_published_schedules': 'priorPublishedSchedules',
            'base_published_schedule': 'basePublishedSchedule',
            'dropped_changes': 'droppedChanges',
            'changes': 'changes'
        }

        self._prior_published_schedules = None
        self._base_published_schedule = None
        self._dropped_changes = None
        self._changes = None

    @property
    def prior_published_schedules(self):
        """
        Gets the prior_published_schedules of this BuAgentScheduleHistoryResponse.
        The list of previously published schedules

        :return: The prior_published_schedules of this BuAgentScheduleHistoryResponse.
        :rtype: list[BuScheduleReference]
        """
        return self._prior_published_schedules

    @prior_published_schedules.setter
    def prior_published_schedules(self, prior_published_schedules):
        """
        Sets the prior_published_schedules of this BuAgentScheduleHistoryResponse.
        The list of previously published schedules

        :param prior_published_schedules: The prior_published_schedules of this BuAgentScheduleHistoryResponse.
        :type: list[BuScheduleReference]
        """
        
        self._prior_published_schedules = prior_published_schedules

    @property
    def base_published_schedule(self):
        """
        Gets the base_published_schedule of this BuAgentScheduleHistoryResponse.
        The originally published agent schedules

        :return: The base_published_schedule of this BuAgentScheduleHistoryResponse.
        :rtype: BuAgentScheduleHistoryChange
        """
        return self._base_published_schedule

    @base_published_schedule.setter
    def base_published_schedule(self, base_published_schedule):
        """
        Sets the base_published_schedule of this BuAgentScheduleHistoryResponse.
        The originally published agent schedules

        :param base_published_schedule: The base_published_schedule of this BuAgentScheduleHistoryResponse.
        :type: BuAgentScheduleHistoryChange
        """
        
        self._base_published_schedule = base_published_schedule

    @property
    def dropped_changes(self):
        """
        Gets the dropped_changes of this BuAgentScheduleHistoryResponse.
        The changes dropped from the schedule history. This will happen if the schedule history is too large

        :return: The dropped_changes of this BuAgentScheduleHistoryResponse.
        :rtype: list[BuAgentScheduleHistoryDroppedChange]
        """
        return self._dropped_changes

    @dropped_changes.setter
    def dropped_changes(self, dropped_changes):
        """
        Sets the dropped_changes of this BuAgentScheduleHistoryResponse.
        The changes dropped from the schedule history. This will happen if the schedule history is too large

        :param dropped_changes: The dropped_changes of this BuAgentScheduleHistoryResponse.
        :type: list[BuAgentScheduleHistoryDroppedChange]
        """
        
        self._dropped_changes = dropped_changes

    @property
    def changes(self):
        """
        Gets the changes of this BuAgentScheduleHistoryResponse.
        The list of changes for the schedule history

        :return: The changes of this BuAgentScheduleHistoryResponse.
        :rtype: list[BuAgentScheduleHistoryChange]
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """
        Sets the changes of this BuAgentScheduleHistoryResponse.
        The list of changes for the schedule history

        :param changes: The changes of this BuAgentScheduleHistoryResponse.
        :type: list[BuAgentScheduleHistoryChange]
        """
        
        self._changes = changes

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AnalyticsSurvey(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsSurvey - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'survey_id': 'str',
            'survey_form_id': 'str',
            'survey_form_name': 'str',
            'survey_form_context_id': 'str',
            'event_time': 'datetime',
            'user_id': 'str',
            'queue_id': 'str',
            'survey_status': 'str',
            'survey_promoter_score': 'int',
            'survey_completed_date': 'datetime',
            'o_survey_total_score': 'int'
        }

        self.attribute_map = {
            'survey_id': 'surveyId',
            'survey_form_id': 'surveyFormId',
            'survey_form_name': 'surveyFormName',
            'survey_form_context_id': 'surveyFormContextId',
            'event_time': 'eventTime',
            'user_id': 'userId',
            'queue_id': 'queueId',
            'survey_status': 'surveyStatus',
            'survey_promoter_score': 'surveyPromoterScore',
            'survey_completed_date': 'surveyCompletedDate',
            'o_survey_total_score': 'oSurveyTotalScore'
        }

        self._survey_id = None
        self._survey_form_id = None
        self._survey_form_name = None
        self._survey_form_context_id = None
        self._event_time = None
        self._user_id = None
        self._queue_id = None
        self._survey_status = None
        self._survey_promoter_score = None
        self._survey_completed_date = None
        self._o_survey_total_score = None

    @property
    def survey_id(self):
        """
        Gets the survey_id of this AnalyticsSurvey.
        Unique identifier for the survey

        :return: The survey_id of this AnalyticsSurvey.
        :rtype: str
        """
        return self._survey_id

    @survey_id.setter
    def survey_id(self, survey_id):
        """
        Sets the survey_id of this AnalyticsSurvey.
        Unique identifier for the survey

        :param survey_id: The survey_id of this AnalyticsSurvey.
        :type: str
        """
        
        self._survey_id = survey_id

    @property
    def survey_form_id(self):
        """
        Gets the survey_form_id of this AnalyticsSurvey.
        Unique identifier for the survey form

        :return: The survey_form_id of this AnalyticsSurvey.
        :rtype: str
        """
        return self._survey_form_id

    @survey_form_id.setter
    def survey_form_id(self, survey_form_id):
        """
        Sets the survey_form_id of this AnalyticsSurvey.
        Unique identifier for the survey form

        :param survey_form_id: The survey_form_id of this AnalyticsSurvey.
        :type: str
        """
        
        self._survey_form_id = survey_form_id

    @property
    def survey_form_name(self):
        """
        Gets the survey_form_name of this AnalyticsSurvey.
        Name of the survey form

        :return: The survey_form_name of this AnalyticsSurvey.
        :rtype: str
        """
        return self._survey_form_name

    @survey_form_name.setter
    def survey_form_name(self, survey_form_name):
        """
        Sets the survey_form_name of this AnalyticsSurvey.
        Name of the survey form

        :param survey_form_name: The survey_form_name of this AnalyticsSurvey.
        :type: str
        """
        
        self._survey_form_name = survey_form_name

    @property
    def survey_form_context_id(self):
        """
        Gets the survey_form_context_id of this AnalyticsSurvey.
        Unique identifier for the survey form, regardless of version

        :return: The survey_form_context_id of this AnalyticsSurvey.
        :rtype: str
        """
        return self._survey_form_context_id

    @survey_form_context_id.setter
    def survey_form_context_id(self, survey_form_context_id):
        """
        Sets the survey_form_context_id of this AnalyticsSurvey.
        Unique identifier for the survey form, regardless of version

        :param survey_form_context_id: The survey_form_context_id of this AnalyticsSurvey.
        :type: str
        """
        
        self._survey_form_context_id = survey_form_context_id

    @property
    def event_time(self):
        """
        Gets the event_time of this AnalyticsSurvey.
        Specifies when a survey occurred. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The event_time of this AnalyticsSurvey.
        :rtype: datetime
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """
        Sets the event_time of this AnalyticsSurvey.
        Specifies when a survey occurred. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param event_time: The event_time of this AnalyticsSurvey.
        :type: datetime
        """
        
        self._event_time = event_time

    @property
    def user_id(self):
        """
        Gets the user_id of this AnalyticsSurvey.
        A unique identifier of the PureCloud user

        :return: The user_id of this AnalyticsSurvey.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this AnalyticsSurvey.
        A unique identifier of the PureCloud user

        :param user_id: The user_id of this AnalyticsSurvey.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def queue_id(self):
        """
        Gets the queue_id of this AnalyticsSurvey.
        Unique identifier for the queue the conversation was on

        :return: The queue_id of this AnalyticsSurvey.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this AnalyticsSurvey.
        Unique identifier for the queue the conversation was on

        :param queue_id: The queue_id of this AnalyticsSurvey.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def survey_status(self):
        """
        Gets the survey_status of this AnalyticsSurvey.
        Survey status

        :return: The survey_status of this AnalyticsSurvey.
        :rtype: str
        """
        return self._survey_status

    @survey_status.setter
    def survey_status(self, survey_status):
        """
        Sets the survey_status of this AnalyticsSurvey.
        Survey status

        :param survey_status: The survey_status of this AnalyticsSurvey.
        :type: str
        """
        
        self._survey_status = survey_status

    @property
    def survey_promoter_score(self):
        """
        Gets the survey_promoter_score of this AnalyticsSurvey.
        Promoter score of the survey

        :return: The survey_promoter_score of this AnalyticsSurvey.
        :rtype: int
        """
        return self._survey_promoter_score

    @survey_promoter_score.setter
    def survey_promoter_score(self, survey_promoter_score):
        """
        Sets the survey_promoter_score of this AnalyticsSurvey.
        Promoter score of the survey

        :param survey_promoter_score: The survey_promoter_score of this AnalyticsSurvey.
        :type: int
        """
        
        self._survey_promoter_score = survey_promoter_score

    @property
    def survey_completed_date(self):
        """
        Gets the survey_completed_date of this AnalyticsSurvey.
        Completion date/time of the survey. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The survey_completed_date of this AnalyticsSurvey.
        :rtype: datetime
        """
        return self._survey_completed_date

    @survey_completed_date.setter
    def survey_completed_date(self, survey_completed_date):
        """
        Sets the survey_completed_date of this AnalyticsSurvey.
        Completion date/time of the survey. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param survey_completed_date: The survey_completed_date of this AnalyticsSurvey.
        :type: datetime
        """
        
        self._survey_completed_date = survey_completed_date

    @property
    def o_survey_total_score(self):
        """
        Gets the o_survey_total_score of this AnalyticsSurvey.


        :return: The o_survey_total_score of this AnalyticsSurvey.
        :rtype: int
        """
        return self._o_survey_total_score

    @o_survey_total_score.setter
    def o_survey_total_score(self, o_survey_total_score):
        """
        Sets the o_survey_total_score of this AnalyticsSurvey.


        :param o_survey_total_score: The o_survey_total_score of this AnalyticsSurvey.
        :type: int
        """
        
        self._o_survey_total_score = o_survey_total_score

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

